@@ -46,14 +46,16 @@ app.config.from_object(__name__)
 
 
 @app.route('/', methods=['POST', 'GET'])
-def heartbeat():
+def index():
     """Use heartbeat."""
-    return request.args.get('heartbeat', '')
+    return '<a href="interactive">interactive</a>'
 
 
 @app.route('/interactive', methods=['POST', 'GET'])
 def interactive():
     """Interactive classifier."""
+    if request.method == 'GET':
+        return request.args.get('heartbeat', '')
     if request.method == 'POST':
         raw_data_json = request.form['drawnJSON']
 
